[−][src]Module rocket_okapi::request
This module contains several traits that correspond to the Rocket traits pertaining to request
guards and responses
Traits
| OpenApiFromData | This trait means that the implementer can be used as a |
| OpenApiFromFormValue | This trait means that the implementer can be used as a |
| OpenApiFromParam | This trait means that the implementer can be used as a |
| OpenApiFromQuery | This trait means that the implementer can be used as a |
| OpenApiFromSegments | This trait means that the implementer can be used as a |