[−][src]Module rocket_okapi::response
Contains the trait OpenApiResponder, meaning that a response implementing this trait can be
documented.
Traits
| OpenApiResponder | Implementing this trait means that any route returning the implementer can be marked with
|